==> membrane_framerate_converter_plugin-0.4.0.tar: mix.exs <==
defmodule Membrane.FramerateConverter.Mixfile do
  use Mix.Project

  @version "0.4.0"
  @github_url "https://github.com/membraneframework/membrane_framerate_converter_plugin"

  def project do
    [
      app: :membrane_framerate_converter_plugin,
      version: @version,
      elixir: "~> 1.12",
      elixirc_paths: elixirc_paths(Mix.env()),
      start_permanent: Mix.env() == :prod,
      deps: deps(),

      # hex
      description: "Plugin for converting framerate of raw video",
      package: package(),

      # docs
      name: "Membrane Framerate Converter plugin",
      source_url: @github_url,
      homepage_url: "https://membraneframework.org",
      docs: docs()
    ]
  end

  def application do
    [
      extra_applications: []
    ]
  end

  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_env), do: ["lib"]

  defp deps do
    [
      {:membrane_core, "~> 0.9.0"},
      {:membrane_raw_video_format, "~> 0.2.0"},
      {:bunch, "~> 1.3"},
      {:ratio, "~> 2.4.2"},
      {:ex_doc, "~> 0.28", only: :dev, runtime: false},
      {:dialyxir, "~> 1.1", only: :dev, runtime: false},
      {:credo, "~> 1.6", only: :dev, runtime: false},
      {:membrane_file_plugin, "~> 0.8", only: :test},
      {:membrane_h264_ffmpeg_plugin, "~> 0.18", only: :test}
    ]
  end

  defp package do
    [
      maintainers: ["Membrane Team"],
      licenses: ["Apache-2.0"],
      links: %{
        "GitHub" => @github_url,
        "Membrane Framework Homepage" => "https://membraneframework.org"
      }
    ]
  end

  defp docs do
    [
      main: "readme",
      extras: ["README.md", "LICENSE"],
      formatters: ["html"],
      source_ref: "v#{@version}",
      nest_modules_by_prefix: [Membrane.FramerateConverter]
    ]
  end
end

==> membrane_framerate_converter_plugin-0.6.0.tar: mix.exs <==
defmodule Membrane.FramerateConverter.Mixfile do
  use Mix.Project

  @version "0.6.0"
  @github_url "https://github.com/membraneframework/membrane_framerate_converter_plugin"

  def project do
    [
      app: :membrane_framerate_converter_plugin,
      version: @version,
      elixir: "~> 1.12",
      elixirc_paths: elixirc_paths(Mix.env()),
      start_permanent: Mix.env() == :prod,
      deps: deps(),
      dialyzer: dialyzer(),

      # hex
      description: "Plugin for converting framerate of raw video",
      package: package(),

      # docs
      name: "Membrane Framerate Converter plugin",
      source_url: @github_url,
      homepage_url: "https://membrane.stream",
      docs: docs()
    ]
  end

  def application do
    [
      extra_applications: []
    ]
  end

  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_env), do: ["lib"]

  defp deps do
    [
      {:membrane_core, "~> 0.11.2"},
      {:membrane_raw_video_format, "~> 0.2.0"},
      {:bunch, "~> 1.3"},
      {:ratio, "~> 2.4.2"},
      {:ex_doc, "~> 0.28", only: :dev, runtime: false},
      {:dialyxir, "~> 1.1", only: :dev, runtime: false},
      {:credo, "~> 1.6", only: :dev, runtime: false},
      {:membrane_file_plugin, "~> 0.13", only: :test},
      {:membrane_h264_ffmpeg_plugin, "~> 0.22", only: :test}
    ]
  end

  defp dialyzer() do
    opts = [
      flags: [:error_handling]
    ]

    if System.get_env("CI") == "true" do
      # Store PLTs in cacheable directory for CI
      [plt_local_path: "priv/plts", plt_core_path: "priv/plts"] ++ opts
    else
      opts
    end
  end

  defp package do
    [
      maintainers: ["Membrane Team"],
      licenses: ["Apache-2.0"],
      links: %{
        "GitHub" => @github_url,
        "Membrane Framework Homepage" => "https://membraneframework.org"
      }
    ]
  end

  defp docs do
    [
      main: "readme",
      extras: ["README.md", "LICENSE"],
      formatters: ["html"],
      source_ref: "v#{@version}",
      nest_modules_by_prefix: [Membrane.FramerateConverter]
    ]
  end
end
